![](/docs/source/_static/climate-lab-logo.png)

# RS Climate Lab

A project focused on climate data and tooling for **Rio Grande do Sul** in Brazil.

## 💁 Contributing

We are extremely open to contributions, whether it be in the form of a new feature, improved infrastructure, or better documentation. Please open an issue to discuss what you want to contribute first so we can coordinate with others that might be working on the same feature.

## 📮 Contact

For questions or comments regarding the usage of this repository, please use the [discussion section](https://github.com/perone/rs-climate-lab/discussions) on Github. For bug reports and feature requests, please open an [issue](https://github.com/perone/rs-climate-lab/issues) on GitHub.

## 🌟 Contributors

[![rs-climate-lab contributors](https://contrib.rocks/image?repo=perone/rs-climate-lab)](https://github.com/perone/rs-climate-lab/graphs/contributors)

### Logo credits

Logo image provided for free by `vecteezy.com`.

